@@ -1,7 +1,7 @@
 use strict;
 package Crypt::Mode::CBC::Easy;
 #ABSTRACT: Encrypts/decrypts text and verifies decrypted text with a checksum and a random initialization vector.
-$Crypt::Mode::CBC::Easy::VERSION = '0.003';
+$Crypt::Mode::CBC::Easy::VERSION = '0.004';
 use Mouse;
 use Crypt::CBC;
 use Digest::SHA;
@@ -84,13 +84,13 @@ sub decrypt {
     croak "must pass in text to be decrypted" unless $cipher_text;
 
     my $separator = $self->separator;
-    my ($iv, $to_decrypt) = split qr/$separator/, MIME::Base64::decode($cipher_text);
+    my ($iv, $to_decrypt) = split $separator, MIME::Base64::decode($cipher_text);
 
     croak "invalid cipher text" unless $iv and $to_decrypt;
 
     my $plain_text_with_checksum = $self->crypt_mode_cbc->decrypt($to_decrypt, $self->key, $iv);
     
-    my @decrypted_values = split($self->separator, $plain_text_with_checksum);
+    my @decrypted_values = split $separator, $plain_text_with_checksum;
     my $digest = pop @decrypted_values;
     my $confirm_digest = $self->_get_digest($iv, \@decrypted_values);
 
@@ -126,7 +126,7 @@ Crypt::Mode::CBC::Easy - Encrypts/decrypts text and verifies decrypted text with
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
